<?php

namespace EventPortal\Tests\Unit\EventSpeaker\Models;

use EventPortal\Domain\Event\Models\EventSpeaker;
use EventPortal\Domain\Speaker\Models\Speaker;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;

class EventSpeakerTest extends TestCase
{
    use RefreshDatabase;

    /** @test **/
    public function can_scope_for_event_and_speaker()
    {
        $eventSpeaker = factory(EventSpeaker::class)->create();

        $actual = EventSpeaker::forEventAndSpeaker($eventSpeaker->event, $eventSpeaker->speaker)->first();

        $this->assertSameModel(EventSpeaker::first(), $actual);
    }

    /** @test **/
    public function can_get_scoped_options()
    {
        factory(EventSpeaker::class)->create([
            'speaker_id' => factory(Speaker::class)->create()->id,
        ]);

        $speaker = factory(Speaker::class)->state('snapshot')->create();
        $eventSpeaker = factory(EventSpeaker::class)->create([
            'speaker_id' => $speaker->id,
        ]);

        $options = EventSpeaker::asScopedOptions(EventSpeaker::where('speaker_id', $speaker->id));

        $this->assertCount(1, $options);
        $option = $options[0];
        $this->assertEquals($speaker->name, $option->label);
        $this->assertEquals($eventSpeaker->id, $option->value);
    }

    /** @test */
    public function can_get_as_option()
    {
        $speaker = factory(Speaker::class)->state('snapshot')->create();
        $eventSpeaker = factory(EventSpeaker::class)->create([
            'speaker_id' => $speaker,
        ]);

        $option = $eventSpeaker->asOption();
        $this->assertEquals($speaker->name, $option->label);
        $this->assertEquals($eventSpeaker->id, $option->value);
    }
}
